# sign list fixed  , can be changed dynamically in future



sign_list = [
    "NO_SIGN",
    "AWAITING_SIGN_A",
    "AWAITING_SIGN_B",
    "AWAITING_SIGN_C",
    "AWAITING_SIGN_D",
    "AWAITING_SIGN_E",
    "AWAITING_SIGN_F",
    "AWAITING_SIGN_G",
    "AWAITING_SIGN_H",
    "AWAITING_SIGN_I",
    "AWAITING_SIGN_J",
    "AWAITING_SIGN_K",
    "AWAITING_SIGN_L",
    "AWAITING_SIGN_M",
    "AWAITING_SIGN_N",
    "AWAITING_SIGN_O",
    "AWAITING_SIGN_P",
    "AWAITING_SIGN_Q",
    "AWAITING_SIGN_R",
    "AWAITING_SIGN_S",
    "AWAITING_SIGN_T",
    "AWAITING_SIGN_U",
    "AWAITING_SIGN_V",
    "AWAITING_SIGN_W",
    "AWAITING_SIGN_X",
    "AWAITING_SIGN_Y",
    "AWAITING_SIGN_Z",
]


sub_action = [
    "MAKER",
    "SIGN_A",
    "SIGN_B",
    "SIGN_C",
    "SIGN_D",
    "SIGN_E",
    "SIGN_F",
    "SIGN_G",
    "SIGN_H",
    "SIGN_I",
    "SIGN_J",
    "SIGN_K",
    "SIGN_L",
    "SIGN_M",
    "SIGN_N",
    "SIGN_O",
    "SIGN_P",
    "SIGN_Q",
    "SIGN_R",
    "SIGN_S",
    "SIGN_T",
    "SIGN_U",
    "SIGN_V",
    "SIGN_W",
    "SIGN_X",
    "SIGN_Y",
    "SIGN_Z",
]